@@ -12,14 +12,11 @@ from easypost.requestor import (
     RequestMethod,
     Requestor,
 )
-from easypost.resource import (
-    AllResource,
-    CreateResource,
-)
+from easypost.resource import AllResource
 from easypost.util import get_lowest_object_rate
 
 
-class Shipment(AllResource, CreateResource):
+class Shipment(AllResource):
     @classmethod
     def create(cls, api_key: Optional[str] = None, with_carbon_offset: Optional[bool] = False, **params) -> "Shipment":
         """Create an Shipment object."""
@@ -50,11 +47,15 @@ class Shipment(AllResource, CreateResource):
         response, _ = requestor.request(method=RequestMethod.GET, url=url)
         return response.get("result", [])
 
-    def buy(self, with_carbon_offset: Optional[bool] = False, **params) -> "Shipment":
+    def buy(
+        self, with_carbon_offset: Optional[bool] = False, end_shipper_id: Optional[str] = None, **params
+    ) -> "Shipment":
         """Buy a shipment."""
         requestor = Requestor(local_api_key=self._api_key)
         url = "%s/%s" % (self.instance_url(), "buy")
         params["carbon_offset"] = with_carbon_offset
+        if end_shipper_id:
+            params["end_shipper_id"] = end_shipper_id
 
         response, api_key = requestor.request(method=RequestMethod.POST, url=url, params=params)
         self.refresh_from(values=response, api_key=api_key)
